Stan Math Library: stan::size_of_helper< T, is_vec > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Static Public Member Functions | List of all members
stan::size_of_helper< T, is_vec > Struct Template Reference

`#include <size_of.hpp>`

## Static Public Member Functions
static size_t | size_of (const T &)

## Detailed Description

### template<typename T, bool is_vec>
struct stan::size_of_helper< T, is_vec >

Definition at line 10 of file size_of.hpp.

## Member Function Documentation

template<typename T, bool is_vec>

static size_t stan::size_of_helper< T, is_vec >::size_of | ( | const T & |  | ) |
| inlinestatic

Definition at line 11 of file size_of.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/scal/meta/size_of.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.